@@ -43,9 +43,10 @@ class WhatsAppValue:
         self.messaging_product = messaging_product
         messages_list = []
         for message in messages:
-            message["_from"] = message["from"]
-            del message["from"]
-            messages_list.append(message)
+            new_message = message.copy()
+            new_message["_from"] = new_message["from"]
+            del new_message["from"]
+            messages_list.append(new_message)
         self.messages = [WhatsAppMessage(**message)
                          for message in messages_list]
         self.metadata = WhatsAppMetadata(**metadata)
@@ -236,6 +237,7 @@ class WhatsAppUpdate:
     def __init__(self, object:str, entry:list[dict]) -> None:
         self.object = object
         self.entry = [WhatsAppEntry(**e) for e in entry]
+        self.entry_json = entry.copy()
 
     def get_from(self) -> str:
         if self.entry[0].changes[0].value.contacts:
