@@ -1,4 +1,4 @@
-from PIL import Image
+
 from io import BytesIO
 
 from digitalguide.WhatsAppUpdate import WhatsAppUpdate
@@ -7,10 +7,14 @@ from configparser import ConfigParser
 from time import sleep
 import requests
 
+import logging
+
 config = ConfigParser()
 config.read("config.ini")
 
 def generate_gif(im1, im2):
+    from PIL import Image
+
     im1 = im1.resize((512, 512))
     im2 = im2.resize((512, 512))
 
@@ -69,7 +73,8 @@ def overlay_images(background, foreground, x_position="left", y_position="up", r
     return background
 
 def whatsapp_eval_image_overlay(client, update: WhatsAppUpdate, context, picture, x_position="left", y_position="up", resize="x"):
-    
+    from PIL import Image
+
     if resize in ["False", "false"]:
         resize = False
 
@@ -78,10 +83,7 @@ def whatsapp_eval_image_overlay(client, update: WhatsAppUpdate, context, picture
 
     media_url = get_media_response.json()["url"]
 
-    media_response = requests.get(media_url, headers=client.headers)
-    im_bytes = media_response.content
-
-    im_file = BytesIO(im_bytes)  # convert image to file-like object
+    im_file = BytesIO(requests.get(media_url, headers=client.headers).content)  # convert image to file-like object
     im1 = Image.open(im_file)   # img is now PIL Image object
     im2 = Image.open(picture)
 
@@ -120,32 +122,25 @@ def whatsapp_eval_image_overlay(client, update: WhatsAppUpdate, context, picture
 def whatsapp_eval_multi_image_overlay(client, update: WhatsAppUpdate, context, overlay_top_left=None, overlay_top_right=None, overlay_bottom_left=None, overlay_bottom_right=None):
     try:
         import requests
+        from PIL import Image
         media_id = update.get_message().image.id
         get_media_response = requests.get(f"{client.base_url}/{media_id}", headers=client.headers)
 
         media_url = get_media_response.json()["url"]
 
-        media_response = requests.get(media_url, headers=client.headers)
-        im_bytes = media_response.content
-
-        im_file = BytesIO(im_bytes)  # convert image to file-like object
-        im1 = Image.open(im_file)   # img is now PIL Image object
+        im1 = Image.open(BytesIO(requests.get(media_url, headers=client.headers).content))   # img is now PIL Image object
 
         if overlay_top_left:
-            overlay_bytes = requests.get(config["space"]["url"] + "/" + overlay_top_left).content
-            im2 = Image.open(BytesIO(overlay_bytes))
+            im2 = Image.open(BytesIO(requests.get(config["space"]["url"] + "/" + overlay_top_left).content))
             im1 = overlay_images(im1, im2, "left","up", True)
         if overlay_top_right:
-            overlay_bytes = requests.get(config["space"]["url"] + "/" + overlay_top_right).content
-            im2 = Image.open(BytesIO(overlay_bytes))
+            im2 = Image.open(BytesIO(requests.get(config["space"]["url"] + "/" + overlay_top_left).content))
             im1 = overlay_images(im1, im2, "right","up", True)
         if overlay_bottom_left:
-            overlay_bytes = requests.get(config["space"]["url"] + "/" + overlay_bottom_left).content
-            im2 = Image.open(BytesIO(overlay_bytes))
+            im2 = Image.open(BytesIO(requests.get(config["space"]["url"] + "/" + overlay_top_left).content))
             im1 = overlay_images(im1, im2, "left","bottom", True)
         if overlay_bottom_right:
-            overlay_bytes = requests.get(config["space"]["url"] + "/" + overlay_bottom_right).content
-            im2 = Image.open(BytesIO(overlay_bytes))
+            im2 = Image.open(BytesIO(requests.get(config["space"]["url"] + "/" + overlay_top_left).content))
             im1 = overlay_images(im1, im2, "right","bottom", True)
 
         bio = BytesIO()
@@ -176,6 +171,7 @@ def whatsapp_eval_multi_image_overlay(client, update: WhatsAppUpdate, context, o
                                 )
         
         client.send_image(config["space"]["url"] + "/" + time_str + "_" + str(update.entry[0].id) + '.png', update.get_from())
+        sleep(2)
     except Exception as e:
         client.send_message("{}".format(e), update.get_from())
 
@@ -183,6 +179,8 @@ def whatsapp_eval_multi_image_overlay(client, update: WhatsAppUpdate, context, o
 
 def whatsapp_eval_gif_generation(client, update: WhatsAppUpdate, context, picture):
     import requests
+    from PIL import Image
+
     try:
         media_id = update.get_message().image.id
         get_media_response = requests.get(f"{client.base_url}/{media_id}", headers=client.headers)
@@ -228,10 +226,22 @@ def whatsapp_eval_gif_generation(client, update: WhatsAppUpdate, context, pictur
     
     client.send_sticker(config["space"]["url"] + "/" + time_str + "_" + str(update.entry[0].id) + '.webp', update.get_from())
 
-    sleep(1)
+    sleep(2)
+
+def whatsapp_function_eval_image_overlay(client, update: WhatsAppUpdate, context, overlay_top_left=None, overlay_top_right=None, overlay_bottom_left=None, overlay_bottom_right=None):
+    payload = {"object":update.object,
+               "entry":update.entry_json,
+               "overlay_top_left": overlay_top_left,
+               "overlay_top_right": overlay_top_right,
+               "overlay_bottom_left": overlay_bottom_left,
+               "overlay_bottom_right": overlay_bottom_right,}
+    
+    logging.info(f"Sending payload to image overlay: {payload}")
+    res = requests.post("https://tiergarten-bot.blauedaecher.com/tiergarten/image_overlay", json=payload)
+    logging.info(f"Response from image overlay: {res.status_code} - {res.text}")
 
 
 whatsapp_action_functions = {"eval_image_overlay": whatsapp_eval_image_overlay,
-                             "eval_multi_image_overlay": whatsapp_eval_multi_image_overlay,
+                             "eval_multi_image_overlay": whatsapp_function_eval_image_overlay,
                              "eval_gif_generation": whatsapp_eval_gif_generation
                              }
